/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.distribution.quickstart;

import java.io.File;

import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.webapp.WebAppContext;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.fractal.fraclet.annotation.annotations.FractalComponent;
import org.objectweb.fractal.fraclet.annotation.annotations.Interface;
import org.objectweb.fractal.fraclet.annotation.annotations.LifeCycle;
import org.objectweb.fractal.fraclet.annotation.annotations.Monolog;
import org.objectweb.fractal.fraclet.annotation.annotations.Provides;
import org.objectweb.fractal.fraclet.annotation.annotations.Requires;
import org.objectweb.fractal.fraclet.annotation.annotations.type.LifeCycleType;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.petals.kernel.configuration.ConfigurationService;
import org.ow2.petals.util.LoggingUtil;

/**
 * 
 * Created on 29 janv. 08
 * 
 * @author Christophe HAMERLING - eBM WebSourcing
 * @since
 * 
 */
@FractalComponent
@Provides(interfaces = @Interface(name = "service", signature = org.ow2.petals.distribution.quickstart.WebConsoleInterface.class))
public class WebConsoleImpl implements WebConsoleInterface {

	@Monolog(name = "logger")
	protected Logger logger;

	private LoggingUtil log;

	@Requires(name = "configuration", signature = org.ow2.petals.kernel.configuration.ConfigurationService.class)
	private ConfigurationService configurationService;

	private Server server;

	@LifeCycle(on = LifeCycleType.START)
	protected void start() throws IllegalLifeCycleException {
		this.log = new LoggingUtil(this.logger);
		int port = Integer.getInteger("jetty.port", 7878).intValue();
		String petalsPath = this.configurationService
				.getContainerConfiguration().getInstallDirectoryPath();
		File workPath = new File(petalsPath, "work");

		this.server = new Server();
		Connector connector = new SelectChannelConnector();
		connector.setPort(port);
		this.server.setConnectors(new Connector[] { connector });

		WebAppContext webapp = new WebAppContext();
		webapp.setContextPath("/");
		webapp.setWar(petalsPath + "/webapps/petals-webconsole.war");
		webapp.setTempDirectory(new File(workPath, "petals-webconsole"));
		webapp.setExtractWAR(true);

		this.server.setHandler(webapp);

		try {
			log.info("Starting embedded Jetty...");
			this.server.start();
			this.log
					.info("The petals-webconsole is available at 'http://localhost:"
							+ port + "'");
		} catch (InterruptedException e) {
			log.warning("Jetty server interrupted !", e);
		} catch (Exception e) {
			log.warning("Can not start Jetty server !", e);
		}
	}

	@LifeCycle(on = LifeCycleType.STOP)
	protected void stop() throws IllegalLifeCycleException {
		log.info("Stopping embedded Jetty...");
		try {
			this.server.stop();
		} catch (Exception e) {
			log.warning("Problem while stopping Jetty server", e);
		}
	}
}
